<?php
/**
 * Winter Theme Options
 *
 * @package WordPress
 * @subpackage Winter
 * @since Winter 1.0
 */
 
 
 
function Winter_theme_options_init() {

	register_setting(
		'Winter_options', 
		'Winter_theme_options', 
		'Winter_theme_options_validate'
	);
	add_settings_section(
		'general', 
		'',
		'__return_false',
		'theme_options' 
	);
	add_settings_field( 'layout',     __( 'Default Layout', 'Winter' ), 'Winter_settings_field_layout',     'theme_options', 'general' );
}
add_action( 'admin_init', 'Winter_theme_options_init' );
function Winter_option_page_capability( $capability ) {
	return 'edit_theme_options';
}
add_filter( 'option_page_capability_Winter_options', 'Winter_option_page_capability' );
function Winter_theme_options_add_page() {
	$theme_page = add_theme_page(
		__( 'Theme Options', 'Winter' ),
		__( 'Theme Options', 'Winter' ),
		'edit_theme_options', 
		'theme_options',
		'Winter_theme_options_render_page' 
	);

	if ( ! $theme_page )
		return;

}
add_action( 'admin_menu', 'Winter_theme_options_add_page' );
function Winter_layouts() {
	$layout_options = array(
		'content-sidebar' => array(
			'value' => 'content-sidebar',
			'label' => __( 'Content on left', 'Winter' ),
			'thumbnail' => get_template_directory_uri() . '/inc/images/content-sidebar.png',
		),
		'sidebar-content' => array(
			'value' => 'sidebar-content',
			'label' => __( 'Content on right', 'Winter' ),
			'thumbnail' => get_template_directory_uri() . '/inc/images/sidebar-content.png',
		),
	);


	return apply_filters( 'Winter_layouts', $layout_options );
}
function Winter_get_default_theme_options() {
	$default_theme_options = array(
		'theme_layout' => 'content-sidebar',
	);

	if ( is_rtl() )
 		$default_theme_options['theme_layout'] = 'sidebar-content';

	return apply_filters( 'Winter_default_theme_options', $default_theme_options );
}
function Winter_get_theme_options() {
	return get_option( 'Winter_theme_options', Winter_get_default_theme_options() );
}
function Winter_settings_field_layout() {
	$options = Winter_get_theme_options();
	foreach ( Winter_layouts() as $layout ) {
		?>

<div class="layout image-radio-option theme-layout">
  <label class="description">
    <input type="radio" name="Winter_theme_options[theme_layout]" value="<?php echo esc_attr( $layout['value'] ); ?>" <?php checked( $options['theme_layout'], $layout['value'] ); ?> />
    <span> <img src="<?php echo esc_url( $layout['thumbnail'] ); ?>" width="136" height="122" alt="" /> <?php echo $layout['label']; ?> </span> </label>
</div>
<?php
	}
}
function Winter_theme_options_render_page() {
	?>
<div class="wrap">
  <?php screen_icon(); ?>
  <?php $theme_name = wp_get_theme('Winter'); ?>
  <h2><?php printf( __( '%s Theme Options', 'Winter' ), $theme_name ); ?></h2>
  <?php settings_errors(); ?>
  <form method="post" action="options.php">
    <?php
				settings_fields( 'Winter_options' );
				do_settings_sections( 'theme_options' );
				submit_button();
			?>
  </form>
</div>
<?php
}

function Winter_theme_options_validate( $input ) {
	$output = $defaults = Winter_get_default_theme_options();
	if ( isset( $input['theme_layout'] ) && array_key_exists( $input['theme_layout'], Winter_layouts() ) )
		$output['theme_layout'] = $input['theme_layout'];

	return apply_filters( 'Winter_theme_options_validate', $output, $input, $defaults );
}
function Winter_layout_classes( $existing_classes ) {
	$options = Winter_get_theme_options();
	$current_layout = $options['theme_layout'];

	if ( in_array( $current_layout, array( 'content-sidebar', 'sidebar-content' ) ) )
		$classes = array( 'two-column' );
	if ( 'content-sidebar' == $current_layout )
		$classes[] = 'right-sidebar';
	elseif ( 'sidebar-content' == $current_layout )
		$classes[] = 'left-sidebar';
	else
		$classes[] = $current_layout;

	$classes = apply_filters( 'Winter_layout_classes', $classes, $current_layout );

	return array_merge( $existing_classes, $classes );
}
add_filter( 'body_class', 'Winter_layout_classes' );
function Winter_customize_register( $wp_customize ) {
	
	$options  = Winter_get_theme_options();
	$defaults = Winter_get_default_theme_options();
	$wp_customize->add_section( 'Winter_layout', array(
		'title'    => __( 'Layout', 'Winter' ),
		'priority' => 50,
	) );

	$wp_customize->add_setting( 'Winter_theme_options[theme_layout]', array(
		'type'              => 'option',
		'default'           => $defaults['theme_layout'],
		'sanitize_callback' => 'sanitize_key',
	) );

	$layouts = Winter_layouts();
	$choices = array();
	foreach ( $layouts as $layout ) {
		$choices[$layout['value']] = $layout['label'];
	}

	$wp_customize->add_control( 'Winter_theme_options[theme_layout]', array(
		'section'    => 'Winter_layout',
		'type'       => 'radio',
		'choices'    => $choices,
	) );
}
add_action( 'customize_register', 'Winter_customize_register' );

function Winter_customize_preview_js() {
	wp_enqueue_script( 'Winter-customizer', get_template_directory_uri() . '/inc/theme-customizer.js', array( 'customize-preview' ), '1.01', true );
}
add_action( 'customize_preview_init', 'Winter_customize_preview_js' );
?>
